@@ -16,9 +16,8 @@ CONFIG_KEYS = (
     'api_version',
     'environment',
 )
-MONITOR_TYPES = ('job', 'event', 'synthetic')
+MONITOR_TYPES = ('job', 'heartbeat', 'check')
 YAML_KEYS = CONFIG_KEYS + tuple(map(lambda t: '{}s'.format(t), MONITOR_TYPES))
-READONLY_KEYS = ('status', 'initialized', 'running', 'disabled', 'passing', 'paused', 'created')
 
 # configuration variables
 api_key = os.getenv('CRONITOR_API_KEY', None)
@@ -52,7 +51,6 @@ class State(object):
     COMPLETE = 'complete'
     FAIL = 'fail'
 
-
 def job(key):
     def wrapper(func):
         @wraps(func)
@@ -76,30 +74,10 @@ def job(key):
         return wrapped
     return wrapper
 
-
 def generate_config():
     config = this.config or './cronitor.yaml'
-    try:
-        monitors = Monitor.all(api_key=api_key)
-        sparse = list(map(lambda x: {k: v for k, v in x.items() if k not in READONLY_KEYS and v is not None}, monitors))
-        jobs = {m['key']: m for m in filter(lambda m: m['type'] == 'job', sparse)}
-        events = {m['key']: m for m in filter(lambda m: m['type'] == 'event', sparse)}
-        synthetics = {m['key']: m for m in filter(lambda m: m['type'] == 'synthetic', sparse)}
-    except (AuthenticationError, APIError) as e:
-        return print(e)
-
-    out = {
-        'api_key': api_key,
-        'api_version': api_version,
-        'environment': environment,
-        'jobs': jobs,
-        'synthetics': synthetics,
-        'events': events,
-
-    }
-    # write them to the config file
     with open(config, 'w') as conf:
-        yaml.dump(out, conf, sort_keys=True)
+        conf.writelines(Monitor.as_yaml())
 
 def validate_config():
     return apply_config(rollback=True)
@@ -107,7 +85,7 @@ def validate_config():
 def apply_config(rollback=False):
     try:
         conf = _parse_config()
-        monitors = Monitor.put(conf.get('monitors'), rollback=rollback)
+        monitors = Monitor.put(conf.get('monitors'), rollback=rollback, timeout=30)
         print("{} monitors {}".format(len(monitors), 'validated.' if rollback else 'synced to Cronitor.'))
     except (ConfigValidationError, APIValidationError, APIError, AuthenticationError) as e:
         logger.error(e)
