@@ -37,30 +37,25 @@ class Monitor(object):
     _req = retry_session(retries=3)
 
     @classmethod
-    def all(cls, api_key=None):
+    def as_yaml(cls, api_key=None):
         api_key = api_key or cronitor.api_key
-
-        page = 1
-        page_size = 50
-        total_count = 50
-        monitors = []
-        while total_count >= ((page-1) * page_size):
-            resp = cls._req.get('{}?page={}'.format(cls._monitor_api_url(), page),
+        resp = cls._req.get('%s.yaml' % cls._monitor_api_url(),
                         auth=(api_key, ''),
                         headers=cls._headers,
                         timeout=10)
-            if resp.ok:
-                data = resp.json()
-                monitors += data.get('monitors', [])
-                total_count = data.get('total_monitor_count', total_count)
-                page += 1
-
-        return monitors
+        if resp.status_code == 200:
+            return resp.text
+        else:
+            raise cronitor.APIError("Unexpected error %s" % resp.text)
 
     @classmethod
     def put(cls, monitors=None, **kwargs):
         api_key = cronitor.api_key
         rollback = False
+        timeout = 10
+        if 'timeout' in kwargs:
+            timeout = kwargs['timeout']
+            del kwargs['timeout']
         if 'rollback' in kwargs:
             rollback = kwargs['rollback']
             del kwargs['rollback']
@@ -71,7 +66,7 @@ class Monitor(object):
             cls._headers['Cronitor-Version'] = kwargs['api_version']
             del kwargs['api_version']
 
-        data = cls._put(monitors or [kwargs], api_key, rollback)
+        data = cls._put(monitors or [kwargs], api_key, rollback, timeout=timeout)
         _monitors = []
         for md in data:
             m = cls(md['key'])
@@ -81,14 +76,14 @@ class Monitor(object):
         return _monitors if len(_monitors) > 1 else _monitors[0]
 
     @classmethod
-    def _put(cls, monitors, api_key, rollback):
+    def _put(cls, monitors, api_key, rollback, timeout=10):
         payload = _prepare_payload(monitors, rollback)
 
         resp = cls._req.put(cls._monitor_api_url(),
                         auth=(api_key, ''),
                         data=json.dumps(payload),
                         headers=cls._headers,
-                        timeout=10)
+                        timeout=timeout)
 
         if resp.status_code == 200:
             return resp.json().get('monitors', [])
